@@ -350,7 +350,7 @@ class WizardBricksStep extends Component {
     handleLvCacheConfig(property, value) {
       const that =this
       const lvCacheConfig = []
-        if(value) {
+        if(value || (property === "lvCacheSize" || property === "ssd")) {
           that.state.lvCacheConfig.forEach(function(eachConfig) {
             eachConfig.lvCache = true
             lvCacheConfig.push(eachConfig)
@@ -624,7 +624,7 @@ class WizardBricksStep extends Component {
                     </a>
                 }
                 <form className="form-horizontal">
-                    <div className="panel-heading gdeploy-wizard-section-title">
+                    <div id="lv-cache-toggle">
                         <input type="checkbox"
                             checked={this.state.lvCacheConfig[this.state.selectedHost.hostIndex].lvCache}
                             onChange={(e) => this.handleLvCacheConfig("lvCache", e.target.checked)}
